@@ -5,7 +5,7 @@ impl Application {
     pub fn new() -> anyhow::Result<Self> {
         let mut windows = Vec::new();
         for i in 0..3 {
-            let window = wita::WindowBuilder::new()
+            let window = wita::Window::builder()
                 .title(format!("wita window {}", i))
                 .position(wita::ScreenPosition::new(30 * i, 30 * i));
             let window = if i > 0 {
