@@ -4,7 +4,7 @@ struct Application {
 
 impl Application {
     fn new() -> anyhow::Result<Self> {
-        wita::WindowBuilder::new()
+        wita::Window::builder()
             .title("wita count")
             .inner_size(wita::LogicalSize::new(256, 256))
             .style(
