@@ -6,7 +6,7 @@ struct Application {
 
 impl Application {
     fn new() -> anyhow::Result<Self> {
-        wita::WindowBuilder::new()
+        wita::Window::builder()
             .title("wita drop files")
             .accept_drag_files(true)
             .build()?;
