@@ -2,7 +2,7 @@ struct Application;
 
 impl Application {
     fn new() -> anyhow::Result<Self> {
-        let window = wita::WindowBuilder::new()
+        let window = wita::Window::builder()
             .title("wita ime")
             .ime(true)
             .visible_ime_composition_window(true)
