@@ -1,11 +1,8 @@
-use windows::Win32::{
-    Foundation::*,
-    UI::WindowsAndMessaging::*,
-};
 use crate::{device::*, event::EventHandler, event::OtherParams, window::LocalWindow};
 use std::any::Any;
 use std::cell::RefCell;
 use std::panic::resume_unwind;
+use windows::Win32::{Foundation::*, UI::WindowsAndMessaging::*};
 
 /// Describes event loop types.
 pub enum RunType {
