@@ -2,6 +2,7 @@
 
 use windows::Win32::Foundation::*;
 
+/// `EventHandler::other` parameters.
 #[derive(Debug)]
 pub struct OtherParams {
     pub hwnd: HWND,
@@ -54,7 +55,7 @@ pub trait EventHandler {
     fn resized(&mut self, window: &Window, size: PhysicalSize<u32>) {}
 
     /// This is called when the window's DPI has been changed.
-    fn dpi_changed(&mut self, window: &Window) {}
+    fn dpi_changed(&mut self, window: &Window, new_dpi: u32) {}
 
     /// This is called when the mouse button has been pressed and released on the window.
     fn mouse_input(
@@ -120,6 +121,7 @@ pub trait EventHandler {
     ) {
     }
 
+    /// This is called when none of defined events.
     fn other(&mut self, params: &OtherParams) -> Option<isize> {
         None
     }
