@@ -1,5 +1,7 @@
 #![allow(clippy::needless_doctest_main)]
 
+#![cfg_attr(docsrs, feature(doc_cfg))]
+
 //! A window library in Rust for Windows.
 //!
 //! `wita` is a library that create a window and run an event loop.
@@ -75,11 +77,12 @@ pub mod ime;
 mod monitor;
 mod procedure;
 #[cfg(any(feature = "raw_input", doc))]
+#[cfg_attr(docsrs, doc(cfg(feature = "raw_input")))]
 pub mod raw_input;
 mod resource;
 mod window;
 #[macro_use]
-pub mod error;
+mod error;
 
 pub use context::RunType;
 pub use device::*;
