@@ -401,7 +401,8 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                     rc.bottom - rc.top,
                     SWP_NOZORDER | SWP_NOACTIVATE,
                 );
-                call_handler(|eh: &mut T, _| eh.dpi_changed(handle));
+                let new_dpi = hiword(wparam.0 as _) as u32;
+                call_handler(|eh: &mut T, _| eh.dpi_changed(handle, new_dpi));
                 let prev_size = prev_rc.right - prev_rc.left;
                 let next_size = rc.right - rc.left;
                 let children = child_windows(hwnd);
@@ -444,7 +445,7 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                         SWP_NOACTIVATE | SWP_NOZORDER,
                     );
                     if let Some(child) = find_window(child) {
-                        call_handler(|eh: &mut T, _| eh.dpi_changed(&child.handle));
+                        call_handler(|eh: &mut T, _| eh.dpi_changed(&child.handle, new_dpi));
                     }
                 }
                 LRESULT(0)
